/**
 * \file ColorSelector.cpp
 * \author Guyet Thomas, AGROCAMPUS-OUEST
 * \version 0.1
 * \date 23 Novembre 2010
 *
 * Module OCI - M2 GL - ISTIC : Correction TP1
 */

#include "ColorSelector.h"

ColorViewer::ColorViewer(Gdk::Color c): Gtk::EventBox(), _color(c)
{
	add(_label);
	set_size_request(20,20);
	modify_bg(Gtk::STATE_NORMAL, _color);
	set_events(Gdk::BUTTON_PRESS_MASK);
}

bool ColorSelector::set_color(GdkEventButton* event, ColorViewer *cv) {
	if(event->button == 3) {
		_background->set_color( cv->get_color() );
	} else {
		_foreground->set_color( cv->get_color() );
	}

	Gdk::Color *color=new Gdk::Color( cv->get_color() );

	m_signal.emit(color);

	return true;
}

ColorSelector::ColorSelector(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder):Gtk::VBox(cobject)
{
	constructWidget();
}

ColorSelector::ColorSelector()
{
	constructWidget();
}

ColorSelector::type_signal_color ColorSelector::signal_changed_color()
{
	return m_signal;
}

void ColorSelector::constructWidget() {
	Gtk::HBox *box2=new Gtk::HBox();

	_background = new Gtk::ColorButton();
	box2->pack_start( *_background, true, true, 3);

	_foreground = new Gtk::ColorButton();
	box2->pack_start( *_foreground, true, true, 3);

	Gtk::HSeparator *sep = new Gtk::HSeparator();
	guint nb=5;
	_colorviewertable=new Gtk::Table(nb, nb, true);

	//Construction des ColorViewer et connexion
	for(guint i=0; i<nb; i++)
		for(guint j=0; j<nb; j++) {
			Gdk::Color c;
			c.set_hsv(360.0*((double)(j*nb+i))/((double)nb*nb+1),1.0, 1.0);
			ColorViewer *cv=new ColorViewer(c);
			cv->signal_button_press_event().connect( sigc::bind<ColorViewer *>(sigc::mem_fun(*this, &ColorSelector::set_color), cv) );
			_colorviewertable->attach(*cv,i,i+1,j,j+1,Gtk::SHRINK,Gtk::SHRINK, 3, 3);
		}

	pack_start( *_colorviewertable, true, true);
	pack_start( *sep, false, false, 3);
	pack_start( *box2, false, false);

	show_all();
}

