
/**
 * \file ColorSelector.h
 * \author Guyet Thomas, AGROCAMPUS-OUEST
 * \version 0.1
 * \date 23 Novembre 2010
 *
 * Module OCI - M2 GL - ISTIC : Correction TP1
 */

#ifndef COLORSELECTOR_H_
#define COLORSELECTOR_H_

#include <gtkmm.h>

/**
 *  \class ColorViewer
 *  \brief Widget pour un label coloré sur lequel on peut cliquer
 */
class ColorViewer : public Gtk::EventBox {
protected:
	Gdk::Color _color;
	Gtk::Label _label;
public:
	ColorViewer(Gdk::Color c);
	virtual ~ColorViewer(){};

	inline Gdk::Color get_color() {return _color;};
};


/**
 * \class ColorSelector
 * \brief Widget pour la sélection de deux couleurs background et foreground par fenêtre de choix ou en utilisant une liste de couleurs prédéfinies.
 */
class ColorSelector : public Gtk::VBox {
public:
	typedef sigc::signal<void, Gdk::Color *> type_signal_color;

	type_signal_color signal_changed_color();

protected:
	Gtk::ColorButton *_background, *_foreground;
	Gtk::Table *_colorviewertable;

	type_signal_color m_signal;

protected:
	/**
	 * \brief Fonction d'attribution d'une couleur à partir de celle d'un ColorViewer
	 * \param event : type d'évènement
	 * \param cv : ColorViewer source de la couleur
	 *
	 * Si event->button==3 (clic droit) on modifie le foreground, sinon on modifie le background.
	 */
	bool set_color(GdkEventButton* event, ColorViewer *cv);


	/**
	 * Fonction décrivant la construction du widget : mise en place des widgets et des connexions.
	 */
	void constructWidget();
public:

	ColorSelector();

	/**
	 * \brief Constructeur pour le chargement par Gtk::Builder
	 */
	ColorSelector(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
	virtual ~ColorSelector(){};

	inline Gdk::Color get_fg() {return _foreground->get_color(); };
	inline Gdk::Color get_bg() {return _background->get_color(); };
};

#endif /* COLORSELECTOR_H_ */
