
/**
 * \file MainDrawingWindow.cpp
 * \author Guyet Thomas, AGROCAMPUS-OUEST
 * \version 0.1
 * \date 23 Novembre 2010
 *
 * Module OCI - M2 GL - ISTIC : Correction TP1
 */

#include "MainDrawingWindow.h"
#include <iostream>


BuilderWindow::BuilderWindow(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder) : Gtk::Window(cobject), _drawing(0), _colormanager(0), _button(0)
{
	builder->get_widget("drawingarea1", _drawing);
	if(!_drawing) {
		std::cerr << "MainDrawingWindow: DrawingArea not found" << std::endl;
		exit(1);
	}
	builder->get_widget_derived("vbox2", _colormanager);
	if(!_colormanager) {
		std::cerr << "MainDrawingWindow: Colormanager not found" << std::endl;
		exit(1);
	}
	builder->get_widget("button1", _button);
	if(!_button) {
		std::cerr << "MainDrawingWindow: Button not found" << std::endl;
		exit(1);
	}
	_button->signal_clicked().connect( sigc::mem_fun(this,&BuilderWindow::on_button_clicked) );

	_colormanager->signal_changed_color().connect( sigc::hide( sigc::mem_fun(this,&BuilderWindow::on_button_clicked) ) );
}

bool BuilderWindow::on_delete_event(GdkEventAny* event)
{
	Gtk::MessageDialog dialog(*this, "Êtes vous sûr de vouloir quitter ?", false /* use_markup */, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL);
	dialog.set_secondary_text("Votre dessin n'a pas été enregistré.");

	int result = dialog.run();

	//Handle the response:
	switch(result)
	{
		case(Gtk::RESPONSE_OK):
			return false;
		case(Gtk::RESPONSE_CANCEL):
			return true;
	}
	return false;
}


void BuilderWindow::on_button_clicked()
{

	//On récupère la couleur depuis le manager :
	Gdk::Color colorfg=_colormanager->get_fg();
	Gdk::Color colorbg=_colormanager->get_bg();

	//Récupération du contexte Cairo pour dessiner dans le DrawingArea
	Cairo::RefPtr<Cairo::Context> cr = _drawing->get_window()->create_cairo_context();

	//Sauve le contexte
	cr->save();

	//Changement des options de dessin

	cr->set_source_rgb(colorfg.get_red_p(), colorfg.get_green_p(), colorfg.get_blue_p());  //< Attention, on utilise les fonction get_blue_p et non get_blue pour récupérer des valeurs entre 0 et 1 (les fonctions get_blue donne une valeur entière entre 0 et 65000 et qqs)
	cr->set_line_width(2.0);

	//Définition du chemin à dessiner
	cr->move_to(10, 10);
	cr->line_to(10, 30);
	cr->line_to(30, 30);
	cr->line_to(30, 10);
	cr->close_path();

	//Réalisation effective du dessin (stroke => tracé de la ligne, preserve => on conserve la forme en mémoire)
	cr->stroke_preserve();

	//Changement de couleur de dessin
	cr->set_source_rgb(colorbg.get_red_p(), colorbg.get_green_p(), colorbg.get_blue_p());
	//Réalisation effective du dessin, mais en utilisant un remplissage
	cr->fill();

	//Restaure le contexte
	cr->restore();
}

ManualWindow::ManualWindow() : Gtk::Window(), _drawing(0), _colormanager(0), _button(0)
{
	 _drawing = new Gtk::DrawingArea();
	 _colormanager = new ColorSelector();
	 _button = new Gtk::Button("button");
	 Gtk::Box *b=new Gtk::HBox();
	 add( *b );

	 Gtk::Separator *sep=new Gtk::VSeparator();
	 Gtk::Separator *sep2=new Gtk::VSeparator();

	 b->pack_start(*_button);
	 b->pack_start(*sep);
	 _drawing->set_size_request(100,100);
	 b->pack_start(*_drawing);
	 b->pack_start(*sep2);
	 b->pack_start(*_colormanager, Gtk::SHRINK, 0);

	 _button->signal_clicked().connect( sigc::mem_fun(this,&ManualWindow::on_button_clicked) );

	 show_all();
}

void ManualWindow::on_button_clicked()
{
	//On récupère la couleur depuis le manager :
	Gdk::Color colorfg=_colormanager->get_fg();
	Gdk::Color colorbg=_colormanager->get_bg();

	//Récupération du contexte Cairo pour dessiner dans le DrawingArea
	Cairo::RefPtr<Cairo::Context> cr = _drawing->get_window()->create_cairo_context();

	//Sauve le contexte
	cr->save();

	//Changement des options de dessin

	cr->set_source_rgb(colorfg.get_red_p(), colorfg.get_green_p(), colorfg.get_blue_p());  //< Attention, on utilise les fonction get_blue_p et non get_blue pour récupérer des valeurs entre 0 et 1 (les fonctions get_blue donne une valeur entière entre 0 et 65000 et qqs)
	cr->set_line_width(2.0);

	//Définition du chemin à dessiner
	cr->move_to(10, 10);
	cr->line_to(10, 30);
	cr->line_to(30, 30);
	cr->line_to(30, 10);
	cr->close_path();

	//Réalisation effective du dessin (stroke => tracé de la ligne, preserve => on conserve la forme en mémoire)
	cr->stroke_preserve();

	//Changement de couleur de dessin
	cr->set_source_rgb(colorbg.get_red_p(), colorbg.get_green_p(), colorbg.get_blue_p());
	//Réalisation effective du dessin, mais en utilisant un remplissage
	cr->fill();

	//Restaure le contexte
	cr->restore();
}

